==> v0.4.9.zip: libarea/app/Languages/ro/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'Mai mult',
    'category'          => 'Categorie',
    'categories'        => 'Categorii',
    'audits'            => 'Audit',
    'soft'              => 'Program',
    'website'           => 'Site-ul web',
    'websites'          => 'Site-uri',
    'on_website'        => 'Spre site',
    'deleted'           => 'la distanta',
    'facets'            => 'Fațete',
    'favorites'         => 'Marcaje',
    'menu'              => 'Meniul',
    'no'                => 'Nu',
    'yes'               => 'Da',
    'title'             => 'Nume',
    'description'       => 'Descriere',
    'catalog'           => 'Catalog',
    'find'              => 'A găsi',
    'help'              => 'Cheie',
    'deny_replies'      => 'Respinge răspunsurile?',
    'posted'            => 'Postat?',
    'necessarily'       => 'Este necesar să se completeze',
    'status'            => 'Stare link',
    'there_program'     => 'Există vreun program?',
    'there_forum'       => 'Site-ul are forum?',
    'there_portal'      => 'Acesta este un portal?',
    'there_blog'        => 'Acesta este un blog personal?',
    'there_reference'   => 'Este acesta un site de referință (enciclopedie)?',
    'hosted_github'     => 'Programul este găzduit pe GitHub?',
    'url_github'        => 'Adresa URL a depozitului GitHub',
    'related_posts'     => 'Postări asemănatoare',
    'desc_formed'       => 'Se formează descrierea',
    'by_date'           => 'După dată',
    'top_view'          => 'Prin rating',
    'new_sites'         => 'Site-uri noi',
    'audits_view'       => 'Necesită luare în considerare',
    'deleted_view'      => 'Îndepărtat',
    'my_website'        => 'Site-urile mele',
    'no_website'        => 'Încă nu există site-uri',
    'bookmarks'         => 'Marcaje site-ul meu',
    'bookmarks_view'    => 'Marcajele mele',
    'no_bookmarks'      => 'Încă nu există marcaje',
    'answers'           => 'Răspunsuri',
    'no_answers'        => 'Niciun răspuns încă...',
    'characters'        => 'Simboluri',
    'remove'            => 'Șterge',
    'reply'             => 'Răspuns',
    'edit'              => 'Schimbare',
    'cancel'            => 'Anulare',
    'add'               => 'Adăuga',
    'markdown'          => 'Markup de reducere',
    'recommended'       => 'Recomandat',
    'my_website_info'   => 'Lista site-urilor adăugate de mine',
    'moderation'        => 'Moderare',
    'sign_in'           => 'Conectare',
    'registration'      => 'înregistrare',
    'site_added'        => 'Site adăugat',

    'closed'            => 'Discuțiile despre site sunt interzise. Autorul sau personalul a închis discuția.',
 
    'audits_home_title' => 'Auditul site-ului',
    'audits_home_desc'  => 'Site-uri luate în considerare',
    'num_website'       => ['Site-ul web', 'Site', 'Site-uri'],
    
    'news'              => 'Știri și mass-media',
    'internet'          => 'Internet',
    'culture'           => 'Cultură și artă',
    'software'          => 'Programe',
    'reference_info'    => 'informații de referință',
    'reference_help'    => 'Enciclopedii, cărți de referință',
    'science'           => 'Știință și educație',
    'goods'             => 'Bunuri si servicii',
    'life'              => 'Acasă',
    'cms'               => 'CMS',
    'life_help'         => 'Copii, animale, hobby-uri...',
    'security'          => 'Siguranță...',
    'society'           => 'Societatea si politica',
    
    'string_length'         => 'Lungime incorectă {name}',
    'website_correctness'   => 'Adresa (URL) site-ului nu este corectă',
    'site_replay'           => 'Un astfel de site există deja în sistem',

    'data_help'         => '<i class="gray-600">Format antet:</i><br> «LibArea» — comunitate<br><br><i class="gray-600">Descriere (fără reclame):</i><br> ...ce este pe site?<i>',
    
    'add_category'      => 'Adăugați o categorie',
    'add_website'       => 'Adăugați site',
    'edit_website'      => 'Editați site-ul',
    
    'sidebar_info'      => 'Catalog de site-uri sistematizate pe rubrici tematice.',
    'banner_info'       => 'Catalog de site-uri cu adnotări și capturi de ecran. <br> Rubricare fațetă, căutare. Marcaje pe resurse cu posibilitatea de a vota site-uri, programe, rating',
    
    'main_title'         => 'Director de site-uri',
    'main_desc'          => 'Lista site-urilor din director plasate în ordine cronologică. Abilitatea de a căuta, marca, sorta după popularitate',
    
    'deleted_title' => 'Site-uri la distanță',
    'deleted_desc'  => '...',
    'audits_title'  => 'Auditul site-ului',
    'audits_desc'   => '...',

    'all'               => 'Toate',
    'github'            => 'GitHub',
    'forum'             => 'Forumuri',
    'blog'              => 'Bloguri',
    'portal'            => 'Portaluri',
    'reference'         => 'Enciclopedii',

    'top_title'         => '{name} — site-uri după popularitate',
    'top_desc'          => 'Anunțată listă de site-uri pe subiect {description_info}',
    'all_title'         => '{name} — rubrică, site-uri după dată',
    'all_desc'          => 'Site-uri în ordine cronologică în rubrica {description_info}',
];

==> v0.5.7.zip: libarea/app/Languages/ro/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'Mai mult',
    'category'          => 'Categorie',
    'categories'        => 'Categorii',
    'audits'            => 'Audit',
    'soft'              => 'Program',
    'website'           => 'Site-ul web',
    'websites'          => 'Site-uri',
    'comments'          => 'Comentarii',
    'on_website'        => 'Spre site',
    'deleted'           => 'la distanta',
    'facets'            => 'Fațete',
    'favorites'         => 'Marcaje',
    'menu'              => 'Meniul',
    'no'                => 'Nu',
    'yes'               => 'Da',
    'title'             => 'Nume',
    'description'       => 'Descriere',
    'catalog'           => 'Catalog',
    'find'              => 'A găsi',
    'help'              => 'Cheie',
    'deny_replies'      => 'Respinge răspunsurile?',
    'posted'            => 'Postat?',
    'necessarily'       => 'Este necesar să se completeze',
    'status'            => 'Stare',
    'refresh'           => 'Reîmprospăta',
    'there_program'     => 'Există vreun program?',
    'there_forum'       => 'Site-ul are forum?',
    'there_portal'      => 'Acesta este un portal?',
    'there_blog'        => 'Acesta este un blog personal?',
    'there_reference'   => 'Este acesta un site de referință (enciclopedie)?',
    'there_goods'       => 'Site-ul oferă produse și servicii?',
    'hosted_github'     => 'Programul este găzduit pe GitHub?',
    'url_github'        => 'Adresa URL a depozitului GitHub',
    'related_posts'     => 'Postări asemănatoare',
    'desc_formed'       => 'Se formează descrierea',
    'by_date'           => 'După dată',
    'top'               => 'TOP',
    'top_view'          => 'Prin rating',
    'new_sites'         => 'Site-uri noi',
    'audits_view'       => 'Necesită luare în considerare',
    'deleted_view'      => 'Îndepărtat',
    'my_website'        => 'Site-urile mele',
    'no_website'        => 'Încă nu există site-uri',
    'bookmarks'         => 'Marcaje site-ul meu',
    'bookmarks_view'    => 'Marcajele mele',
    'no_bookmarks'      => 'Încă nu există marcaje',
    'answers'           => 'Răspunsuri',
    'no_answers'        => 'Niciun răspuns încă...',
    'characters'        => 'Simboluri',
    'remove'            => 'Șterge',
    'reply'             => 'Răspuns',
    'edit'              => 'Schimbare',
    'cancel'            => 'Anulare',
    'add'               => 'Adăuga',
    'markdown'          => 'Markup de reducere',
    'recommended'       => 'Recomandat',
    'my_website_info'   => 'Lista site-urilor adăugate de mine',
    'moderation'        => 'Moderare',
    'sign_in'           => 'Conectare',
    'registration'      => 'înregistrare',
    'site_added'        => 'Site adăugat',

    'closed'            => 'Discuțiile despre site sunt interzise. Autorul sau personalul a închis discuția.',

    'screenshot_time'   => 'Realizarea unei capturi de ecran poate dura ceva timp.',
 
    'audits_home_title' => 'Auditul site-ului',
    'audits_home_desc'  => 'Site-uri luate în considerare',
    'num_website'       => ['Site-ul web', 'Site', 'Site-uri'],
    
    'news'              => 'Știri și mass-media',
    'internet'          => 'Internet',
    'culture'           => 'Cultură și artă',
    'software'          => 'Programe',
    'reference_info'    => 'informații de referință',
    'reference_help'    => 'Enciclopedii, cărți de referință',
    'science'           => 'Știință și educație',
    'goods'             => 'Bunuri si servicii',
    'business'          => 'Afaceri',
    'life'              => 'Acasă',
    'cms'               => 'CMS',
    'life_help'         => 'Copii, animale, hobby-uri...',
    'security'          => 'Siguranță...',
    'society'           => 'Societatea si politica',

    'contact_information'   => 'Informatii de contact',
    'telephone'             => 'Telefon',
    'email'                 => 'Email',
    'vk'                    => 'VKontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => 'Lungime incorectă {name}',
    'website_correctness'   => 'Adresa (URL) site-ului nu este corectă',
    'site_replay'           => 'Un astfel de site există deja în sistem',

    'data_help'         => '<i class="gray-600">Format antet:</i><br> «LibArea» — comunitate<br><br><i class="gray-600">Descriere (fără reclame):</i><br> ...ce este pe site?',
    'admin_help'         => 'Secțiune închisă disponibilă numai personalului',
    
    'add_category'      => 'Adăugați o categorie',
    'add_website'       => 'Adăugați site',
    'edit_website'      => 'Editați site-ul',
    
    'sidebar_info'      => 'Catalog de site-uri sistematizate pe rubrici tematice.',
    'banner_info'       => 'Catalog de site-uri cu adnotări și capturi de ecran. <br> Rubricare fațetă, căutare. Marcaje pe resurse cu posibilitatea de a vota site-uri, programe, rating',
    
    'main_title'         => 'Director de site-uri',
    'main_desc'          => 'Lista site-urilor din director plasate în ordine cronologică. Abilitatea de a căuta, marca, sorta după popularitate',
    
    'deleted_title' => 'Site-uri la distanță',
    'audits_title'  => 'Auditul site-ului',

    'all'               => 'Toate',
    'github'            => 'GitHub',
    'forum'             => 'Forumuri',
    'blog'              => 'Bloguri',
    'portal'            => 'Portaluri',
    'reference'         => 'Enciclopedii',

    'top_title'         => '{name} — site-uri după popularitate',
    'top_desc'          => 'Anunțată listă de site-uri pe subiect {description_info}',
    'all_title'         => '{name} — rubrică, site-uri după dată',
    'all_desc'          => 'Site-uri în ordine cronologică în rubrica {description_info}',
];
